@@ -23,7 +23,7 @@
 
 #include "fs/filesystem.h"
 
-#include <qglobal.h>
+#include <QtGlobal>
 
 class Report;
 
@@ -40,57 +40,57 @@ public:
     exfat(qint64 firstsector, qint64 lastsector, qint64 sectorsused, const QString& label);
 
 public:
-    static void init();
+    void init() override;
 
-//          virtual qint64 readUsedCapacity(const QString& deviceNode) const;
-    virtual bool check(Report& report, const QString& deviceNode) const;
-    virtual bool create(Report& report, const QString& deviceNode) const;
-//          virtual bool resize(Report& report, const QString& deviceNode, qint64 length) const;
-    virtual bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel);
-    virtual bool updateUUID(Report& report, const QString& deviceNode) const;
+//          qint64 readUsedCapacity(const QString& deviceNode) const override;
+    bool check(Report& report, const QString& deviceNode) const override;
+    bool create(Report& report, const QString& deviceNode) const override;
+//          bool resize(Report& report, const QString& deviceNode, qint64 length) const override;
+    bool writeLabel(Report& report, const QString& deviceNode, const QString& newLabel) override;
+    bool updateUUID(Report& report, const QString& deviceNode) const override;
 
-    virtual CommandSupportType supportGetUsed() const {
+    CommandSupportType supportGetUsed() const override {
         return m_GetUsed;
     }
-    virtual CommandSupportType supportGetLabel() const {
+    CommandSupportType supportGetLabel() const override {
         return m_GetLabel;
     }
-    virtual CommandSupportType supportCreate() const {
+    CommandSupportType supportCreate() const override {
         return m_Create;
     }
-    virtual CommandSupportType supportGrow() const {
+    CommandSupportType supportGrow() const override {
         return m_Grow;
     }
-    virtual CommandSupportType supportShrink() const {
+    CommandSupportType supportShrink() const override {
         return m_Shrink;
     }
-    virtual CommandSupportType supportMove() const {
+    CommandSupportType supportMove() const override {
         return m_Move;
     }
-    virtual CommandSupportType supportCheck() const {
+    CommandSupportType supportCheck() const override {
         return m_Check;
     }
-    virtual CommandSupportType supportCopy() const {
+    CommandSupportType supportCopy() const override {
         return m_Copy;
     }
-    virtual CommandSupportType supportBackup() const {
+    CommandSupportType supportBackup() const override {
         return m_Backup;
     }
-    virtual CommandSupportType supportSetLabel() const {
+    CommandSupportType supportSetLabel() const override {
         return m_SetLabel;
     }
-    virtual CommandSupportType supportUpdateUUID() const {
+    CommandSupportType supportUpdateUUID() const override {
         return m_UpdateUUID;
     }
-    virtual CommandSupportType supportGetUUID() const {
+    CommandSupportType supportGetUUID() const override {
         return m_GetUUID;
     }
 
-//          virtual qint64 minCapacity() const;
-    virtual qint64 maxCapacity() const;
-    virtual qint64 maxLabelLength() const;
-    virtual SupportTool supportToolName() const;
-    virtual bool supportToolFound() const;
+//          qint64 minCapacity() const;
+    qint64 maxCapacity() const override;
+    qint64 maxLabelLength() const override;
+    SupportTool supportToolName() const override;
+    bool supportToolFound() const override;
 
 public:
     static CommandSupportType m_GetUsed;
