@@ -94,7 +94,7 @@ FileSystem::SupportTool f2fs::supportToolName() const
 
 qint64 f2fs::minCapacity() const
 {
-    return 128 * Capacity::unitFactor(Capacity::Byte, Capacity::MiB); // FIXME
+    return 30 * Capacity::unitFactor(Capacity::Byte, Capacity::MiB);
 }
 
 qint64 f2fs::maxCapacity() const
@@ -109,13 +109,13 @@ qint64 f2fs::maxLabelLength() const
 
 bool f2fs::check(Report& report, const QString& deviceNode) const
 {
-    ExternalCommand cmd(report, QStringLiteral("fsck.f2fs"), QStringList() << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("fsck.f2fs"), { deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
 bool f2fs::create(Report& report, const QString& deviceNode) const
 {
-    ExternalCommand cmd(report, QStringLiteral("mkfs.f2fs"), QStringList() << deviceNode);
+    ExternalCommand cmd(report, QStringLiteral("mkfs.f2fs"), { deviceNode });
     return cmd.run(-1) && cmd.exitCode() == 0;
 }
 
