@@ -1,5 +1,6 @@
 /*************************************************************************
  *  Copyright (C) 2012 by Volker Lanz <vl@fidra.de>                      *
+ *  Copyright (C) 2015 by Teo Mrnjavac <teo@kde.org>                     *
  *  Copyright (C) 2016 by Andrius Štikonas <andrius@stikonas.eu>         *
  *                                                                       *
  *  This program is free software; you can redistribute it and/or        *
@@ -18,12 +19,17 @@
 
 #include "fs/filesystem.h"
 
+#include "backend/corebackend.h"
+#include "backend/corebackendmanager.h"
+
 #include "util/externalcommand.h"
 #include "util/capacity.h"
 
 #include <blkid/blkid.h>
+
 #include <KLocalizedString>
 
+#include <QDebug>
 
 const std::array< QColor, FileSystem::__lastType > FileSystem::defaultColorCode =
 {
@@ -105,6 +111,11 @@ static QString readBlkIdValue(const QString& deviceNode, const QString& tag)
     return rval;
 }
 
+FileSystem::Type FileSystem::detectFileSystem(const QString& partitionPath)
+{
+    return CoreBackendManager::self()->backend()->detectFileSystem(partitionPath);
+}
+
 /** Reads the label for this FileSystem
     @param deviceNode the device node for the Partition the FileSystem is on
     @return the FileSystem label or an empty string in case of error
@@ -127,7 +138,7 @@ bool FileSystem::create(Report& report, const QString& deviceNode) const
     return true;
 }
 
-/** Resized a FileSystem to a given new length
+/** Resize a FileSystem to a given new length
     @param report Report to write status information to
     @param deviceNode the device node for the Partition the FileSystem is on
     @param newLength the new length for the FileSystem in bytes
@@ -145,7 +156,7 @@ bool FileSystem::resize(Report& report, const QString& deviceNode, qint64 newLen
 /** Move a FileSystem to a new start sector
     @param report Report to write status information to
     @param deviceNode the device node for the Partition the FileSystem is on
-    @param newLength the new start sector for the FileSystem
+    @param newStartSector the new start sector for the FileSystem
     @return true on success
 */
 bool FileSystem::move(Report& report, const QString& deviceNode, qint64 newStartSector) const
@@ -382,26 +393,46 @@ void FileSystem::move(qint64 newStartSector)
     setFirstSector(newStartSector);
     setLastSector(newStartSector + savedLength - 1);
 }
+bool FileSystem::canMount(const QString& deviceNode, const QString& mountPoint) const
+{
+    Q_UNUSED(deviceNode);
+    // cannot mount if we have no mount points
+    return !mountPoint.isEmpty();
+}
 
 /** Attempt to mount this FileSystem on a given mount point
+    @param report the report to write information to
+    @param deviceNode the path to the device that is to be unmounted
     @param mountPoint the mount point to mount the FileSystem on
     @return true on success
 */
-bool FileSystem::mount(const QString& mountPoint)
+bool FileSystem::mount(Report& report, const QString &deviceNode, const QString &mountPoint)
 {
-    Q_UNUSED(mountPoint);
-
+    ExternalCommand mountCmd(   report,
+                                QStringLiteral("mount"),
+                              { QStringLiteral("--verbose"),
+                                deviceNode,
+                                mountPoint });
+    if (mountCmd.run() && mountCmd.exitCode() == 0) {
+        return true;
+    }
     return false;
 }
 
 /** Attempt to unmount this FileSystem
-    @param mountPoint the mount point the FileSystem is mounted on
+    @param report the report to write information to
+    @param deviceNode the path to the device that is to be unmounted
     @return true on success
  */
-bool FileSystem::unmount(const QString& mountPoint)
+bool FileSystem::unmount(Report& report, const QString& deviceNode)
 {
-    Q_UNUSED(mountPoint);
-
+    ExternalCommand umountCmd(  report,
+                                QStringLiteral("umount"),
+                              { QStringLiteral("--verbose"),
+                                QStringLiteral("--all-targets"),
+                                deviceNode });
+    if ( umountCmd.run() && umountCmd.exitCode() == 0 )
+        return true;
     return false;
 }
 
