@@ -20,11 +20,11 @@
 
 #define CREATEPARTITIONTABLEOPERATION__H
 
-#include "../util/libpartitionmanagerexport.h"
+#include "util/libpartitionmanagerexport.h"
 
-#include "../ops/operation.h"
+#include "ops/operation.h"
 
-#include "../core/partitiontable.h"
+#include "core/partitiontable.h"
 
 #include <QString>
 
@@ -38,7 +38,6 @@ class OperationStack;
 */
 class LIBKPMCORE_EXPORT CreatePartitionTableOperation : public Operation
 {
-    Q_OBJECT
     Q_DISABLE_COPY(CreatePartitionTableOperation)
 
     friend class OperationStack;
@@ -49,16 +48,16 @@ public:
     ~CreatePartitionTableOperation();
 
 public:
-    QString iconName() const {
+    QString iconName() const override {
         return QStringLiteral("edit-clear");
     }
-    QString description() const;
-    void preview();
-    void undo();
-    bool execute(Report& parent);
+    QString description() const override;
+    void preview() override;
+    void undo() override;
+    bool execute(Report& parent) override;
 
-    virtual bool targets(const Device& d) const;
-    virtual bool targets(const Partition&) const {
+    bool targets(const Device& d) const override;
+    bool targets(const Partition&) const  override{
         return false;
     }
 
