@@ -31,6 +31,7 @@
 
 #include "fs/filesystem.h"
 #include "fs/filesystemfactory.h"
+#include "fs/luks.h"
 
 #include "util/capacity.h"
 #include "util/report.h"
@@ -198,6 +199,9 @@ bool RestoreOperation::canRestore(const Partition* p)
     if (p->roles().has(PartitionRole::Extended))
         return false;
 
+    if (p->roles().has(PartitionRole::Luks))
+        return FS::luks::mapperName(p->deviceNode()).isEmpty();
+
     return true;
 }
 /** Creates a new Partition to restore to.
