@@ -32,12 +32,13 @@
     @param args the arguments to pass to the command
 */
 ExternalCommand::ExternalCommand(const QString& cmd, const QStringList& args) :
+    QProcess(),
     m_Report(nullptr),
+    m_Command(cmd),
+    m_Args(args),
     m_ExitCode(-1),
     m_Output()
 {
-    m_Command.push_back(cmd);
-    m_Args.push_back(args);
     setup();
 }
 
@@ -47,35 +48,7 @@ ExternalCommand::ExternalCommand(const QString& cmd, const QStringList& args) :
     @param args the arguments to pass to the command
  */
 ExternalCommand::ExternalCommand(Report& report, const QString& cmd, const QStringList& args) :
-    m_Report(report.newChild()),
-    m_ExitCode(-1),
-    m_Output()
-{
-    m_Command.push_back(cmd);
-    m_Args.push_back(args);
-    setup();
-}
-
-/** Creates a new ExternalCommand instance without Report.
-    @param cmd the vector of the piped commands to run
-    @param args the vector of the arguments to pass to the commands
-*/
-ExternalCommand::ExternalCommand(const std::vector<QString> cmd, const std::vector<QStringList> args) :
-    m_Report(nullptr),
-    m_Command(cmd),
-    m_Args(args),
-    m_ExitCode(-1),
-    m_Output()
-{
-    setup();
-}
-
-/** Creates a new ExternalCommand instance with Report.
-    @param report the Report to write output to.
-    @param cmd the vector of the piped commands to run
-    @param args the vector of the arguments to pass to the commands
- */
-ExternalCommand::ExternalCommand(Report& report, const std::vector<QString> cmd, const std::vector<QStringList> args) :
+    QProcess(),
     m_Report(report.newChild()),
     m_Command(cmd),
     m_Args(args),
@@ -85,72 +58,52 @@ ExternalCommand::ExternalCommand(Report& report, const std::vector<QString> cmd,
     setup();
 }
 
-ExternalCommand::~ExternalCommand()
-{
-    delete[] processes;
-}
-
 void ExternalCommand::setup()
 {
     setEnvironment(QStringList() << QStringLiteral("LC_ALL=C") << QStringLiteral("PATH=") + QString::fromUtf8(getenv("PATH")));
     setProcessChannelMode(MergedChannels);
 
-    processes = new QProcess[command().size()];
-    connect(&processes[command().size() - 1], SIGNAL(readyReadStandardOutput()), SLOT(onReadOutput()));
-    connect(&processes[command().size() - 1], SIGNAL(finished(int, QProcess::ExitStatus)), SLOT(onFinished(int)));
-
-    for (unsigned int i = 0; i < command().size() - 1; i++) {
-        processes[i].setStandardOutputProcess(&processes[i + 1]);
-    }
+    connect(this, static_cast<void(QProcess::*)(int, QProcess::ExitStatus)>(&QProcess::finished), this, &ExternalCommand::onFinished);
+    connect(this, &ExternalCommand::readyReadStandardOutput, this, &ExternalCommand::onReadOutput);
 }
 
-/** Starts the external commands.
+/** Starts the external command.
     @param timeout timeout to wait for the process to start
     @return true on success
 */
 bool ExternalCommand::start(int timeout)
 {
-    for (unsigned int i = 0; i < command().size(); i++)
-        processes[i].start(command()[i], args()[i]);
+    QProcess::start(command(), args());
 
     if (report()) {
-        QString s;
-        for (unsigned int i = 0; i < command().size(); i++) {
-            s += command()[i] + QStringLiteral(" ") + args()[i].join(QStringLiteral(" "));
-            if (i < command().size() - 1)
-                s += QStringLiteral(" | ");
-        }
-        report()->setCommand(i18nc("@info/plain", "Command: %1", s));
+        report()->setCommand(i18nc("@info/plain", "Command: %1 %2", command(), args().join(QStringLiteral(" "))));
     }
 
-    for (unsigned int i = 0; i < command().size(); i++) {
-        if (!processes[i].waitForStarted(timeout)) {
-            if (report())
-                report()->line() << i18nc("@info/plain", "(Command timeout while starting \"%1\")", command()[i] + QStringLiteral(" ") + args()[i].join(QStringLiteral(" ")));
-
-            return false;
-        }
+    if (!waitForStarted(timeout))
+    {
+        if (report())
+            report()->line() << i18nc("@info/plain", "(Command timeout while starting)");
+        return false;
     }
 
     return true;
 }
 
-/** Waits for the external commands to finish.
+/** Waits for the external command to finish.
     @param timeout timeout to wait until the process finishes.
     @return true on success
 */
 bool ExternalCommand::waitFor(int timeout)
 {
-    for (unsigned int i = 0; i < command().size(); i++) {
-        processes[i].closeWriteChannel();
+    closeWriteChannel();
 
-        if (!processes[i].waitForFinished(timeout)) {
-            if (report())
-                report()->line() << i18nc("@info/plain", "(Command timeout while running \"%1\")", command()[i] + QStringLiteral(" ") + args()[i].join(QStringLiteral(" ")));
-            return false;
-        }
-        onReadOutput();
+    if (!waitForFinished(timeout)) {
+        if (report())
+            report()->line() << i18nc("@info/plain", "(Command timeout while running)");
+        return false;
     }
+
+    onReadOutput();
     return true;
 }
 
@@ -165,7 +118,7 @@ bool ExternalCommand::run(int timeout)
 
 void ExternalCommand::onReadOutput()
 {
-    const QString s = QString::fromUtf8(processes[command().size() - 1].readAllStandardOutput());
+    const QString s = QString::fromUtf8(readAllStandardOutput());
 
     m_Output += s;
 
@@ -173,7 +126,8 @@ void ExternalCommand::onReadOutput()
         *report() << s;
 }
 
-void ExternalCommand::onFinished(int exitCode)
+void ExternalCommand::onFinished(int exitCode, QProcess::ExitStatus exitStatus)
 {
+    Q_UNUSED(exitStatus)
     setExitCode(exitCode);
 }
